Class: Spoom::Deadcode::Definition::Status

Inherits:
Object
  • Object
show all
Defined in:
lib/spoom/deadcode/definition.rb

Constant Summary collapse

ALIVE =

A definition is marked as ALIVE if it has at least one reference with the same name

new
DEAD =

A definition is marked as DEAD if it has no reference with the same name

new
IGNORED =

A definition can be marked as IGNORED if it is not relevant for the analysis

new