Class: Spoom::LSP::Request
- Defined in:
- lib/spoom/sorbet/lsp/base.rb
Overview
A request message to describe a request between the client and the server.
Every processed request must send a response back to the sender of the request.
Instance Attribute Summary collapse
- #id ⇒ Object readonly
- #params ⇒ Object readonly
Instance Method Summary collapse
-
#initialize(id, method, params) ⇒ Request
constructor
A new instance of Request.
Methods inherited from Message
Constructor Details
#initialize(id, method, params) ⇒ Request
Returns a new instance of Request.
43 44 45 46 47 48 |
# File 'lib/spoom/sorbet/lsp/base.rb', line 43 def initialize(id, method, params) super() @id = id @method = method @params = params end |
Instance Attribute Details
#id ⇒ Object (readonly)
37 38 39 |
# File 'lib/spoom/sorbet/lsp/base.rb', line 37 def id @id end |
#params ⇒ Object (readonly)
40 41 42 |
# File 'lib/spoom/sorbet/lsp/base.rb', line 40 def params @params end |