Class: Spoom::Deadcode::Definition::Status
- Inherits:
-
Object
- Object
- Spoom::Deadcode::Definition::Status
- Defined in:
- lib/spoom/deadcode/definition.rb
Constant Summary collapse
- ALIVE =
A definition is marked as
ALIVEif it has at least one reference with the same name new- DEAD =
A definition is marked as
DEADif it has no reference with the same name new- IGNORED =
A definition can be marked as
IGNOREDif it is not relevant for the analysis new